@@ -177,6 +177,7 @@ struct _grn_table_queue {
   grn_id head;
   grn_id tail;
   grn_id cap;
+  grn_bool unblock_requested;
 };
 
 GRN_API void grn_array_queue_lock_clear(grn_ctx *ctx, grn_array *array);
@@ -205,6 +206,7 @@ struct _grn_hash {
   uint32_t *max_offset;
   grn_obj *tokenizer;
   grn_obj *normalizer;
+  grn_obj token_filters;
 
   /* For grn_io_hash. */
   grn_io *io;
