@@ -22,12 +22,19 @@
 #include "groonga_in.h"
 #include "ctx.h"
 
+#ifdef GRN_WITH_MRUBY
+# include <mruby.h>
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-void grn_ctx_impl_mrb_init(grn_ctx *ctx);
-void grn_ctx_impl_mrb_fin(grn_ctx *ctx);
+#ifdef GRN_WITH_MRUBY
+GRN_API mrb_value grn_mrb_eval(grn_ctx *ctx, const char *script, int script_length);
+GRN_API mrb_value grn_mrb_load(grn_ctx *ctx, const char *path);
+GRN_API grn_rc grn_mrb_to_grn(grn_ctx *ctx, mrb_value mrb_object, grn_obj *grn_object);
+#endif
 
 #ifdef __cplusplus
 }
