@@ -270,7 +270,12 @@ module Groonga
       return false if !(lower_condition?(op) or lower_condition?(next_op))
       return false if !(upper_condition?(op) or upper_condition?(next_op))
 
-      data.args[0] == next_data.args[0] and data.indexes == next_data.indexes
+      return false if data.args[0] != next_data.args[0]
+
+      data_indexes = data.indexes
+      return false if data_indexes.empty?
+
+      data_indexes == next_data.indexes
     end
 
     def lower_condition?(operator)
@@ -293,7 +298,7 @@ module Groonga
 
     def create_between_data(data, next_data)
       between_data = ScanInfoData.new(data.start)
-      between_data.end = next_data.end
+      between_data.end = next_data.end + 1
       between_data.flags = data.flags
       between_data.op = Operator::CALL
       between_data.logical_op = data.logical_op
