@@ -1,5 +1,5 @@
 /* -*- c-basic-offset: 2 -*- */
-/* Copyright(C) 2009-2012 Brazil
+/* Copyright(C) 2009-2014 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -203,7 +203,8 @@ grn_ra_cache_fin(grn_ctx *ctx, grn_ra *ra, grn_id id)
 
 /**** jagged arrays ****/
 
-#define GRN_JA_W_SEGREGATE_THRESH      7
+#define GRN_JA_W_SEGREGATE_THRESH_V1   7
+#define GRN_JA_W_SEGREGATE_THRESH_V2   16
 #define GRN_JA_W_CAPACITY              38
 #define GRN_JA_W_SEGMENT               22
 
@@ -215,7 +216,8 @@ grn_ra_cache_fin(grn_ctx *ctx, grn_ra *ra, grn_id id)
 #define JA_N_EINFO_IN_A_SEGMENT        (1U << JA_W_EINFO_IN_A_SEGMENT)
 #define JA_M_EINFO_IN_A_SEGMENT        (JA_N_EINFO_IN_A_SEGMENT - 1)
 #define JA_N_GARBAGES_IN_A_SEGMENT     ((1U << (GRN_JA_W_SEGMENT - 3)) - 2)
-#define JA_N_ELEMENT_VARIATION         (GRN_JA_W_SEGREGATE_THRESH - JA_W_EINFO + 1)
+#define JA_N_ELEMENT_VARIATION_V1      (GRN_JA_W_SEGREGATE_THRESH_V1 - JA_W_EINFO + 1)
+#define JA_N_ELEMENT_VARIATION_V2      (GRN_JA_W_SEGREGATE_THRESH_V2 - JA_W_EINFO + 1)
 #define JA_N_DSEGMENTS                 (1U << JA_W_SEGMENTS_MAX)
 #define JA_N_ESEGMENTS                 (1U << (GRN_ID_WIDTH - JA_W_EINFO_IN_A_SEGMENT))
 
@@ -282,18 +284,46 @@ typedef struct {
   ja_pos recs[JA_N_GARBAGES_IN_A_SEGMENT];
 } grn_ja_ginfo;
 
-struct grn_ja_header {
+struct grn_ja_header_v1 {
   uint32_t flags;
   uint32_t curr_seg;
   uint32_t curr_pos;
   uint32_t max_element_size;
-  ja_pos free_elements[JA_N_ELEMENT_VARIATION];
-  uint32_t garbages[JA_N_ELEMENT_VARIATION];
-  uint32_t ngarbages[JA_N_ELEMENT_VARIATION];
+  ja_pos free_elements[JA_N_ELEMENT_VARIATION_V1];
+  uint32_t garbages[JA_N_ELEMENT_VARIATION_V1];
+  uint32_t ngarbages[JA_N_ELEMENT_VARIATION_V1];
   uint32_t dsegs[JA_N_DSEGMENTS];
   uint32_t esegs[JA_N_ESEGMENTS];
 };
 
+struct grn_ja_header_v2 {
+  uint32_t flags;
+  uint32_t curr_seg;
+  uint32_t curr_pos;
+  uint32_t max_element_size;
+  ja_pos free_elements[JA_N_ELEMENT_VARIATION_V2];
+  uint32_t garbages[JA_N_ELEMENT_VARIATION_V2];
+  uint32_t ngarbages[JA_N_ELEMENT_VARIATION_V2];
+  uint32_t dsegs[JA_N_DSEGMENTS];
+  uint32_t esegs[JA_N_ESEGMENTS];
+  uint8_t segregate_threshold;
+  uint8_t n_element_variation;
+};
+
+struct grn_ja_header {
+  uint32_t flags;
+  uint32_t *curr_seg;
+  uint32_t *curr_pos;
+  uint32_t max_element_size;
+  ja_pos *free_elements;
+  uint32_t *garbages;
+  uint32_t *ngarbages;
+  uint32_t *dsegs;
+  uint32_t *esegs;
+  uint8_t segregate_threshold;
+  uint8_t n_element_variation;
+};
+
 #define SEG_SEQ        (0x10000000U)
 #define SEG_HUGE       (0x20000000U)
 #define SEG_EINFO      (0x30000000U)
@@ -308,6 +338,8 @@ struct grn_ja_header {
 #define SEGMENTS_GINFO_ON(ja,seg,width) (SEGMENTS_AT(ja,seg) = SEG_GINFO|(width))
 #define SEGMENTS_OFF(ja,seg) (SEGMENTS_AT(ja,seg) = 0)
 
+grn_bool grn_ja_skip_same_value_put = GRN_TRUE;
+
 static grn_ja *
 _grn_ja_create(grn_ctx *ctx, grn_ja *ja, const char *path,
                unsigned int max_element_size, uint32_t flags)
@@ -315,18 +347,41 @@ _grn_ja_create(grn_ctx *ctx, grn_ja *ja, const char *path,
   int i;
   grn_io *io;
   struct grn_ja_header *header;
-  io = grn_io_create(ctx, path, sizeof(struct grn_ja_header),
+  struct grn_ja_header_v2 *header_v2;
+  io = grn_io_create(ctx, path, sizeof(struct grn_ja_header_v2),
                      JA_SEGMENT_SIZE, JA_N_DSEGMENTS, grn_io_auto,
                      GRN_IO_EXPIRE_SEGMENT);
   if (!io) { return NULL; }
   grn_io_set_type(io, GRN_COLUMN_VAR_SIZE);
-  header = grn_io_header(io);
-  header->curr_pos = JA_SEGMENT_SIZE;
-  header->flags = flags;
-  for (i = 0; i < JA_N_ESEGMENTS; i++) { header->esegs[i] = JA_ESEG_VOID; }
+
+  header_v2 = grn_io_header(io);
+  header_v2->flags = flags;
+  header_v2->curr_seg = 0;
+  header_v2->curr_pos = JA_SEGMENT_SIZE;
+  header_v2->max_element_size = max_element_size;
+  for (i = 0; i < JA_N_ESEGMENTS; i++) { header_v2->esegs[i] = JA_ESEG_VOID; }
+  header_v2->segregate_threshold = GRN_JA_W_SEGREGATE_THRESH_V2;
+  header_v2->n_element_variation = JA_N_ELEMENT_VARIATION_V2;
+
+  header = GRN_GMALLOC(sizeof(struct grn_ja_header));
+  if (!header) {
+    grn_io_close(ctx, io);
+    return NULL;
+  }
+  header->flags               = header_v2->flags;
+  header->curr_seg            = &(header_v2->curr_seg);
+  header->curr_pos            = &(header_v2->curr_pos);
+  header->max_element_size    = header_v2->max_element_size;
+  header->free_elements       = header_v2->free_elements;
+  header->garbages            = header_v2->garbages;
+  header->ngarbages           = header_v2->ngarbages;
+  header->dsegs               = header_v2->dsegs;
+  header->esegs               = header_v2->esegs;
+  header->segregate_threshold = header_v2->segregate_threshold;
+  header->n_element_variation = header_v2->n_element_variation;
+
   ja->io = io;
   ja->header = header;
-  header->max_element_size = max_element_size;
   SEGMENTS_EINFO_ON(ja, 0, 0);
   header->esegs[0] = 0;
   return ja;
@@ -353,21 +408,56 @@ grn_ja_open(grn_ctx *ctx, const char *path)
   grn_io *io;
   grn_ja *ja = NULL;
   struct grn_ja_header *header;
+  struct grn_ja_header_v2 *header_v2;
   io = grn_io_open(ctx, path, grn_io_auto);
   if (!io) { return NULL; }
-  header = grn_io_header(io);
+  header_v2 = grn_io_header(io);
   if (grn_io_get_type(io) != GRN_COLUMN_VAR_SIZE) {
     ERR(GRN_INVALID_FORMAT, "file type unmatch");
     grn_io_close(ctx, io);
     return NULL;
   }
+  if (header_v2->segregate_threshold == 0) {
+    header_v2->segregate_threshold = GRN_JA_W_SEGREGATE_THRESH_V1;
+  }
+  if (header_v2->n_element_variation == 0) {
+    header_v2->n_element_variation = JA_N_ELEMENT_VARIATION_V1;
+  }
   if (!(ja = GRN_GMALLOC(sizeof(grn_ja)))) {
     grn_io_close(ctx, io);
     return NULL;
   }
   GRN_DB_OBJ_SET_TYPE(ja, GRN_COLUMN_VAR_SIZE);
+  if (!(header = GRN_GMALLOC(sizeof(struct grn_ja_header)))) {
+    grn_io_close(ctx, io);
+    GRN_GFREE(ja);
+    return NULL;
+  }
+
+  header->flags               = header_v2->flags;
+  header->curr_seg            = &(header_v2->curr_seg);
+  header->curr_pos            = &(header_v2->curr_pos);
+  header->max_element_size    = header_v2->max_element_size;
+  header->segregate_threshold = header_v2->segregate_threshold;
+  header->n_element_variation = header_v2->n_element_variation;
+  if (header->segregate_threshold == GRN_JA_W_SEGREGATE_THRESH_V1) {
+    struct grn_ja_header_v1 *header_v1 = (struct grn_ja_header_v1 *)header_v2;
+    header->free_elements = header_v1->free_elements;
+    header->garbages      = header_v1->garbages;
+    header->ngarbages     = header_v1->ngarbages;
+    header->dsegs         = header_v1->dsegs;
+    header->esegs         = header_v1->esegs;
+  } else {
+    header->free_elements = header_v2->free_elements;
+    header->garbages      = header_v2->garbages;
+    header->ngarbages     = header_v2->ngarbages;
+    header->dsegs         = header_v2->dsegs;
+    header->esegs         = header_v2->esegs;
+  }
+
   ja->io = io;
   ja->header = header;
+
   return ja;
 }
 
@@ -385,6 +475,7 @@ grn_ja_close(grn_ctx *ctx, grn_ja *ja)
   grn_rc rc;
   if (!ja) { return GRN_INVALID_ARGUMENT; }
   rc = grn_io_close(ctx, ja->io);
+  GRN_GFREE(ja->header);
   GRN_GFREE(ja);
   return rc;
 }
@@ -417,6 +508,7 @@ grn_ja_truncate(grn_ctx *ctx, grn_ja *ja)
   if ((rc = grn_io_close(ctx, ja->io))) { goto exit; }
   ja->io = NULL;
   if (path && (rc = grn_io_remove(ctx, path))) { goto exit; }
+  GRN_GFREE(ja->header);
   if (!_grn_ja_create(ctx, ja, path, max_element_size, flags)) {
     rc = GRN_UNKNOWN_ERROR;
   }
@@ -492,7 +584,7 @@ grn_ja_free(grn_ctx *ctx, grn_ja *ja, grn_ja_einfo *einfo)
     GRN_BIT_SCAN_REV(es, m);
     m++;
   }
-  if (m > GRN_JA_W_SEGREGATE_THRESH) {
+  if (m > ja->header->segregate_threshold) {
     byte *addr = NULL;
     GRN_IO_SEG_REF(ja->io, seg, addr);
     if (!addr) { return GRN_NO_MEMORY_AVAILABLE; }
@@ -506,8 +598,8 @@ grn_ja_free(grn_ctx *ctx, grn_ja *ja, grn_ja_einfo *einfo)
     if (SEGMENTS_AT(ja, seg) == SEG_SEQ) {
       /* reuse the segment */
       SEGMENTS_OFF(ja, seg);
-      if (seg == ja->header->curr_seg) {
-        ja->header->curr_pos = JA_SEGMENT_SIZE;
+      if (seg == *(ja->header->curr_seg)) {
+        *(ja->header->curr_pos) = JA_SEGMENT_SIZE;
       }
     }
     GRN_IO_SEG_UNREF(ja->io, seg);
@@ -557,31 +649,45 @@ grn_ja_free(grn_ctx *ctx, grn_ja *ja, grn_ja_einfo *einfo)
 }
 
 grn_rc
-grn_ja_replace(grn_ctx *ctx, grn_ja *ja, grn_id id, grn_ja_einfo *ei, uint64_t *cas)
+grn_ja_replace(grn_ctx *ctx, grn_ja *ja, grn_id id,
+               grn_ja_einfo *ei, uint64_t *cas)
 {
+  grn_rc rc = GRN_SUCCESS;
   uint32_t lseg, *pseg, pos;
   grn_ja_einfo *einfo = NULL, eback;
   lseg = id >> JA_W_EINFO_IN_A_SEGMENT;
   pos = id & JA_M_EINFO_IN_A_SEGMENT;
   pseg = &ja->header->esegs[lseg];
-  if (grn_io_lock(ctx, ja->io, 10000000)) { return ctx->rc; }
+  if (grn_io_lock(ctx, ja->io, grn_lock_timeout)) {
+    return ctx->rc;
+  }
   if (*pseg == JA_ESEG_VOID) {
     int i = 0;
     while (SEGMENTS_AT(ja, i)) {
       if (++i >= JA_N_DSEGMENTS) {
         ERR(GRN_NOT_ENOUGH_SPACE, "grn_ja file (%s) is full", ja->io->path);
+        rc = GRN_NOT_ENOUGH_SPACE;
         goto exit;
       }
     }
     SEGMENTS_EINFO_ON(ja, i, lseg);
-    *pseg = i;
+    GRN_IO_SEG_REF(ja->io, i, einfo);
+    if (einfo) {
+      *pseg = i;
+      memset(einfo, 0, JA_SEGMENT_SIZE);
+    }
+  } else {
+    GRN_IO_SEG_REF(ja->io, *pseg, einfo);
+  }
+  if (!einfo) {
+    rc = GRN_NO_MEMORY_AVAILABLE;
+    goto exit;
   }
-  GRN_IO_SEG_REF(ja->io, *pseg, einfo);
-  if (!einfo) { goto exit; }
   eback = einfo[pos];
   if (cas && *cas != *((uint64_t *)&eback)) {
     ERR(GRN_CAS_ERROR, "cas failed (%d)", id);
     GRN_IO_SEG_UNREF(ja->io, *pseg);
+    rc = GRN_CAS_ERROR;
     goto exit;
   }
   // smb_wmb();
@@ -594,7 +700,7 @@ grn_ja_replace(grn_ctx *ctx, grn_ja *ja, grn_id id, grn_ja_einfo *ei, uint64_t *
   grn_ja_free(ctx, ja, &eback);
 exit :
   grn_io_unlock(ja->io);
-  return ctx->rc;
+  return rc;
 }
 
 #define JA_N_GARBAGES_TH 10
@@ -615,7 +721,7 @@ grn_ja_alloc(grn_ctx *ctx, grn_ja *ja, grn_id id,
     return GRN_SUCCESS;
   }
   iw->tiny_p = 0;
-  if (grn_io_lock(ctx, ja->io, 10000000)) { return ctx->rc; }
+  if (grn_io_lock(ctx, ja->io, grn_lock_timeout)) { return ctx->rc; }
   if (element_size + sizeof(grn_id) > JA_SEGMENT_SIZE) {
     int i, j, n = (element_size + JA_SEGMENT_SIZE - 1) >> GRN_JA_W_SEGMENT;
     for (i = 0, j = -1; i < JA_N_DSEGMENTS; i++) {
@@ -644,8 +750,9 @@ grn_ja_alloc(grn_ctx *ctx, grn_ja *ja, grn_id id,
     int m, aligned_size, es = element_size - 1;
     GRN_BIT_SCAN_REV(es, m);
     m++;
-    if (m > GRN_JA_W_SEGREGATE_THRESH) {
-      uint32_t seg = ja->header->curr_seg, pos = ja->header->curr_pos;
+    if (m > ja->header->segregate_threshold) {
+      uint32_t seg = *(ja->header->curr_seg);
+      uint32_t pos = *(ja->header->curr_pos);
       if (pos + element_size + sizeof(grn_id) > JA_SEGMENT_SIZE) {
         seg = 0;
         while (SEGMENTS_AT(ja, seg)) {
@@ -656,7 +763,7 @@ grn_ja_alloc(grn_ctx *ctx, grn_ja *ja, grn_id id,
           }
         }
         SEGMENTS_SEQ_ON(ja, seg);
-        ja->header->curr_seg = seg;
+        *(ja->header->curr_seg) = seg;
         pos = 0;
       }
       GRN_IO_SEG_REF(ja->io, seg, addr);
@@ -674,7 +781,7 @@ grn_ja_alloc(grn_ctx *ctx, grn_ja *ja, grn_id id,
       EINFO_ENC(einfo, seg, pos, element_size);
       iw->segment = seg;
       iw->addr = addr + pos;
-      ja->header->curr_pos = pos + aligned_size;
+      *(ja->header->curr_pos) = pos + aligned_size;
       grn_io_unlock(ja->io);
       return GRN_SUCCESS;
     } else {
@@ -786,6 +893,25 @@ grn_ja_put_raw(grn_ctx *ctx, grn_ja *ja, grn_id id,
   int64_t buf;
   grn_io_win iw;
   grn_ja_einfo einfo;
+
+  if (grn_ja_skip_same_value_put &&
+      (flags & GRN_OBJ_SET_MASK) == GRN_OBJ_SET &&
+      value_len > 0) {
+    grn_io_win jw;
+    uint32_t old_len;
+    void *old_value;
+    grn_bool same_value = GRN_FALSE;
+
+    old_value = grn_ja_ref(ctx, ja, id, &jw, &old_len);
+    if (value_len == old_len && memcmp(value, old_value, value_len) == 0) {
+      same_value = GRN_TRUE;
+    }
+    grn_ja_unref(ctx, &jw);
+    if (same_value) {
+      return GRN_SUCCESS;
+    }
+  }
+
   switch (flags & GRN_OBJ_SET_MASK) {
   case GRN_OBJ_APPEND :
     if (value_len) {
@@ -809,7 +935,7 @@ grn_ja_put_raw(grn_ctx *ctx, grn_ja *ja, grn_id id,
               memcpy(b + pos, value, value_len);
               *((uint32_t *)(b + el)) = pos + value_len;
             }
-            return ctx->rc;
+            return GRN_SUCCESS;
           } else {
             if ((rc = grn_ja_alloc(ctx, ja, id,
                                    value_len + old_len + sizeof(uint32_t),
@@ -859,7 +985,7 @@ grn_ja_put_raw(grn_ctx *ctx, grn_ja *ja, grn_id id,
               memcpy(b + pos - value_len, value, value_len);
               *((uint32_t *)(b + el)) = pos - value_len;
             }
-            return ctx->rc;
+            return GRN_SUCCESS;
           } else {
             if ((rc = grn_ja_alloc(ctx, ja, id,
                                    value_len + old_len + sizeof(uint32_t),
@@ -928,17 +1054,15 @@ grn_ja_put_raw(grn_ctx *ctx, grn_ja *ja, grn_id id,
     break;
   default :
     ERR(GRN_INVALID_ARGUMENT, "grn_ja_put_raw called with illegal flags value");
-    return ctx->rc;
+    return GRN_INVALID_ARGUMENT;
   }
-  if (grn_ja_replace(ctx, ja, id, &einfo, cas)) {
-    grn_rc rc = ctx->rc;
-    ctx->rc = GRN_SUCCESS;
-    if (grn_io_lock(ctx, ja->io, 10000000)) { return ctx->rc; }
-    grn_ja_free(ctx, ja, &einfo);
-    grn_io_unlock(ja->io);
-    ctx->rc = rc;
+  if ((rc = grn_ja_replace(ctx, ja, id, &einfo, cas))) {
+    if (!grn_io_lock(ctx, ja->io, grn_lock_timeout)) {
+      grn_ja_free(ctx, ja, &einfo);
+      grn_io_unlock(ja->io);
+    }
   }
-  return ctx->rc;
+  return rc;
 }
 
 grn_rc
@@ -1046,7 +1170,7 @@ grn_ja_element_info(grn_ctx *ctx, grn_ja *ja, grn_id id,
   return GRN_SUCCESS;
 }
 
-#ifdef WITH_ZLIB
+#ifdef GRN_WITH_ZLIB
 #include <zlib.h>
 
 static void *
@@ -1090,9 +1214,9 @@ grn_ja_ref_zlib(grn_ctx *ctx, grn_ja *ja, grn_id id, grn_io_win *iw, uint32_t *v
   }
   return value;
 }
-#endif /* WITH_ZLIB */
+#endif /* GRN_WITH_ZLIB */
 
-#ifdef WITH_LZO
+#ifdef GRN_WITH_LZO
 #include <lzo/lzo1x.h>
 
 static void *
@@ -1128,21 +1252,21 @@ grn_ja_ref_lzo(grn_ctx *ctx, grn_ja *ja, grn_id id, grn_io_win *iw, uint32_t *va
   *value_len = lout_len;
   return value;
 }
-#endif /* WITH_LZO */
+#endif /* GRN_WITH_LZO */
 
 void *
 grn_ja_ref(grn_ctx *ctx, grn_ja *ja, grn_id id, grn_io_win *iw, uint32_t *value_len)
 {
-#ifdef WITH_ZLIB
+#ifdef GRN_WITH_ZLIB
   if (ja->header->flags & GRN_OBJ_COMPRESS_ZLIB) {
     return grn_ja_ref_zlib(ctx, ja, id, iw, value_len);
   }
-#endif /* WITH_ZLIB */
-#ifdef WITH_LZO
+#endif /* GRN_WITH_ZLIB */
+#ifdef GRN_WITH_LZO
   if (ja->header->flags & GRN_OBJ_COMPRESS_LZO) {
     return grn_ja_ref_lzo(ctx, ja, id, iw, value_len);
   }
-#endif /* WITH_LZO */
+#endif /* GRN_WITH_LZO */
   return grn_ja_ref_raw(ctx, ja, id, iw, value_len);
 }
 
@@ -1176,7 +1300,7 @@ exit :
   return value;
 }
 
-#ifdef WITH_ZLIB
+#ifdef GRN_WITH_ZLIB
 inline static grn_rc
 grn_ja_put_zlib(grn_ctx *ctx, grn_ja *ja, grn_id id,
                 void *value, uint32_t value_len, int flags, uint64_t *cas)
@@ -1202,7 +1326,7 @@ grn_ja_put_zlib(grn_ctx *ctx, grn_ja *ja, grn_id id,
     return ctx->rc;
   }
   zvalue_len = deflateBound(&zstream, value_len);
-  if (!(zvalue = GRN_MALLOC(zvalue_len + sizeof (uint64_t)))) { deflateEnd(&zstream); return GRN_NO_MEMORY_AVAILABLE; }
+  if (!(zvalue = GRN_MALLOC(zvalue_len + sizeof(uint64_t)))) { deflateEnd(&zstream); return GRN_NO_MEMORY_AVAILABLE; }
   zstream.next_out = (Bytef *)(((uint64_t *)zvalue) + 1);
   zstream.avail_out = zvalue_len;
   if (deflate(&zstream, Z_FINISH) != Z_STREAM_END) {
@@ -1218,13 +1342,13 @@ grn_ja_put_zlib(grn_ctx *ctx, grn_ja *ja, grn_id id,
     return ctx->rc;
   }
   *(uint64_t *)zvalue = value_len;
-  rc = grn_ja_put_raw(ctx, ja, id, zvalue, zvalue_len + sizeof (uint64_t), flags, cas);
+  rc = grn_ja_put_raw(ctx, ja, id, zvalue, zvalue_len + sizeof(uint64_t), flags, cas);
   GRN_FREE(zvalue);
   return rc;
 }
-#endif /* WITH_ZLIB */
+#endif /* GRN_WITH_ZLIB */
 
-#ifdef WITH_LZO
+#ifdef GRN_WITH_LZO
 inline static grn_rc
 grn_ja_put_lzo(grn_ctx *ctx, grn_ja *ja, grn_id id,
                void *value, uint32_t value_len, int flags, uint64_t *cas)
@@ -1237,7 +1361,7 @@ grn_ja_put_lzo(grn_ctx *ctx, grn_ja *ja, grn_id id,
     return grn_ja_put_raw(ctx, ja, id, value, value_len, flags, cas);
   }
 
-  if (!(lvalue = GRN_MALLOC(lvalue_len + sizeof (uint64_t)))) { return GRN_NO_MEMORY_AVAILABLE; }
+  if (!(lvalue = GRN_MALLOC(lvalue_len + sizeof(uint64_t)))) { return GRN_NO_MEMORY_AVAILABLE; }
   if (!(lwork = GRN_MALLOC(LZO1X_1_MEM_COMPRESS))) { GRN_FREE(lvalue); return GRN_NO_MEMORY_AVAILABLE; }
   if (lzo1x_1_compress(value, value_len, (lzo_bytep)((uint64_t *)lvalue + 1), &lvalue_len, lwork) != LZO_E_OK) {
     GRN_FREE(lwork);
@@ -1247,26 +1371,26 @@ grn_ja_put_lzo(grn_ctx *ctx, grn_ja *ja, grn_id id,
   }
   GRN_FREE(lwork);
   *(uint64_t *)lvalue = value_len;
-  rc = grn_ja_put_raw(ctx, ja, id, lvalue, lvalue_len + sizeof (uint64_t), flags, cas);
+  rc = grn_ja_put_raw(ctx, ja, id, lvalue, lvalue_len + sizeof(uint64_t), flags, cas);
   GRN_FREE(lvalue);
   return rc;
 }
-#endif /* WITH_LZO */
+#endif /* GRN_WITH_LZO */
 
 grn_rc
 grn_ja_put(grn_ctx *ctx, grn_ja *ja, grn_id id, void *value, uint32_t value_len,
            int flags, uint64_t *cas)
 {
-#ifdef WITH_ZLIB
+#ifdef GRN_WITH_ZLIB
   if (ja->header->flags & GRN_OBJ_COMPRESS_ZLIB) {
     return grn_ja_put_zlib(ctx, ja, id, value, value_len, flags, cas);
   }
-#endif /* WITH_ZLIB */
-#ifdef WITH_LZO
+#endif /* GRN_WITH_ZLIB */
+#ifdef GRN_WITH_LZO
   if (ja->header->flags & GRN_OBJ_COMPRESS_LZO) {
     return grn_ja_put_lzo(ctx, ja, id, value, value_len, flags, cas);
   }
-#endif /* WITH_LZO */
+#endif /* GRN_WITH_LZO */
   return grn_ja_put_raw(ctx, ja, id, value, value_len, flags, cas);
 }
 
@@ -1317,7 +1441,7 @@ grn_ja_defrag(grn_ctx *ctx, grn_ja *ja, int threshold)
   int nsegs = 0;
   uint32_t seg, ts = 1U << (GRN_JA_W_SEGMENT - threshold);
   for (seg = 0; seg < JA_N_DSEGMENTS; seg++) {
-    if (seg == ja->header->curr_seg) { continue; }
+    if (seg == *(ja->header->curr_seg)) { continue; }
     if (((SEGMENTS_AT(ja, seg) & SEG_MASK) == SEG_SEQ) &&
         ((SEGMENTS_AT(ja, seg) & ~SEG_MASK) < ts)) {
       if (!grn_ja_defrag_seg(ctx, ja, seg)) { nsegs++; }
@@ -1338,11 +1462,15 @@ grn_ja_check(grn_ctx *ctx, grn_ja *ja)
   grn_itoh(h->flags, buf, 8);
   GRN_OUTPUT_STR(buf, 8);
   GRN_OUTPUT_CSTR("curr seg");
-  GRN_OUTPUT_INT64(h->curr_seg);
+  GRN_OUTPUT_INT64(*(h->curr_seg));
   GRN_OUTPUT_CSTR("curr pos");
-  GRN_OUTPUT_INT64(h->curr_pos);
+  GRN_OUTPUT_INT64(*(h->curr_pos));
   GRN_OUTPUT_CSTR("max_element_size");
   GRN_OUTPUT_INT64(h->max_element_size);
+  GRN_OUTPUT_CSTR("segregate_threshold");
+  GRN_OUTPUT_INT64(h->segregate_threshold);
+  GRN_OUTPUT_CSTR("n_element_variation");
+  GRN_OUTPUT_INT64(h->n_element_variation);
   GRN_OUTPUT_MAP_CLOSE();
   GRN_OUTPUT_ARRAY_OPEN("DETAIL", -1);
   for (seg = 0; seg < JA_N_DSEGMENTS; seg++) {
