@@ -1,5 +1,5 @@
 /* -*- c-basic-offset: 2 -*- */
-/* Copyright(C) 2010-2013 Brazil
+/* Copyright(C) 2010-2014 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -251,6 +251,9 @@ grn_proc_inspect(grn_ctx *ctx, grn_obj *buf, grn_obj *obj)
   case GRN_PROC_NORMALIZER :
     GRN_TEXT_PUTS(ctx, buf, "normalizer");
     break;
+  case GRN_PROC_TOKEN_FILTER :
+    GRN_TEXT_PUTS(ctx, buf, "token-filter");
+    break;
   }
   GRN_TEXT_PUTS(ctx, buf, " ");
 
@@ -1107,7 +1110,7 @@ grn_win32_base_dir(void)
                                                     absolute_dll_filename,
                                                     MAX_PATH);
     if (absolute_dll_filename_size == 0) {
-      win32_base_dir = ".";
+      win32_base_dir = strdup(".");
     } else {
       DWORD ansi_dll_filename_size;
       ansi_dll_filename_size =
@@ -1115,7 +1118,7 @@ grn_win32_base_dir(void)
                             absolute_dll_filename, absolute_dll_filename_size,
                             NULL, 0, NULL, NULL);
       if (ansi_dll_filename_size == 0) {
-        win32_base_dir = ".";
+        win32_base_dir = strdup(".");
       } else {
         char *path;
         win32_base_dir = malloc(ansi_dll_filename_size + 1);
