@@ -1,5 +1,5 @@
 /* -*- c-basic-offset: 2; indent-tabs-mode: nil -*- */
-/* Copyright(C) 2010-2013 Brazil
+/* Copyright(C) 2010-2014 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -23,11 +23,9 @@
 #include <groonga/plugin.h>
 #include <string.h>
 
-#ifndef HAVE_STRNCASECMP
-# ifdef HAVE__STRNICMP
-#  define strncasecmp(s1,s2,n) _strnicmp(s1,s2,n)
-# endif /* HAVE__STRNICMP */
-#endif /* HAVE_STRNCASECMP */
+#ifdef HAVE__STRNICMP
+# define strncasecmp(s1,s2,n) _strnicmp(s1,s2,n)
+#endif /* HAVE__STRNICMP */
 
 #define VAR GRN_PROC_GET_VAR_BY_OFFSET
 #define CONST_STR_LEN(x) x, x ? sizeof(x) - 1 : 0
@@ -890,14 +888,15 @@ learner_learn_for_suggest(grn_ctx *ctx, grn_suggest_learner *learner)
   int keylen = grn_table_get_key(ctx, learner->items, learner->post_item_id,
                                  keybuf, GRN_TABLE_MAX_KEY_SIZE);
   unsigned int token_flags = 0;
-  grn_token *token = grn_token_open(ctx, learner->items, keybuf, keylen,
-                                    GRN_TOKEN_ADD, token_flags);
-  if (token) {
+  grn_token_cursor *token_cursor =
+    grn_token_cursor_open(ctx, learner->items, keybuf, keylen,
+                          GRN_TOKEN_ADD, token_flags);
+  if (token_cursor) {
     grn_id tid;
     grn_obj *pre_item = &(learner->pre_item);
     grn_obj *post_item = learner->post_item;
     grn_hash *token_ids = NULL;
-    while ((tid = grn_token_next(ctx, token)) && tid != learner->post_item_id) {
+    while ((tid = grn_token_cursor_next(ctx, token_cursor)) && tid != learner->post_item_id) {
       uint64_t key;
       int added;
       grn_id pair_id;
@@ -926,7 +925,7 @@ learner_learn_for_suggest(grn_ctx *ctx, grn_suggest_learner *learner)
     if (token_ids) {
       grn_hash_close(ctx, token_ids);
     }
-    grn_token_close(ctx, token);
+    grn_token_cursor_close(ctx, token_cursor);
   }
 }
 
@@ -996,34 +995,21 @@ GRN_PLUGIN_INIT(grn_ctx *ctx)
 grn_rc
 GRN_PLUGIN_REGISTER(grn_ctx *ctx)
 {
-  grn_expr_var vars[] = {
-    {CONST_STR_LEN("types")},
-    {CONST_STR_LEN("table")},
-    {CONST_STR_LEN("column")},
-    {CONST_STR_LEN("query")},
-    {CONST_STR_LEN("sortby")},
-    {CONST_STR_LEN("output_columns")},
-    {CONST_STR_LEN("offset")},
-    {CONST_STR_LEN("limit")},
-    {CONST_STR_LEN("frequency_threshold")},
-    {CONST_STR_LEN("conditional_probability_threshold")},
-    {CONST_STR_LEN("prefix_search")},
-    {CONST_STR_LEN("similar_search")}
-  };
-  GRN_TEXT_INIT(&vars[0].value, 0);
-  GRN_TEXT_INIT(&vars[1].value, 0);
-  GRN_TEXT_INIT(&vars[2].value, 0);
-  GRN_TEXT_INIT(&vars[3].value, 0);
-  GRN_TEXT_INIT(&vars[4].value, 0);
-  GRN_TEXT_INIT(&vars[5].value, 0);
-  GRN_TEXT_INIT(&vars[6].value, 0);
-  GRN_TEXT_INIT(&vars[7].value, 0);
-  GRN_TEXT_INIT(&vars[8].value, 0);
-  GRN_TEXT_INIT(&vars[9].value, 0);
-  GRN_TEXT_INIT(&vars[10].value, 0);
-  GRN_TEXT_INIT(&vars[11].value, 0);
-  grn_proc_create(ctx, CONST_STR_LEN("suggest"), GRN_PROC_COMMAND,
-                  command_suggest, NULL, NULL, 12, vars);
+  grn_expr_var vars[12];
+
+  grn_plugin_expr_var_init(ctx, &vars[0], "types", -1);
+  grn_plugin_expr_var_init(ctx, &vars[1], "table", -1);
+  grn_plugin_expr_var_init(ctx, &vars[2], "column", -1);
+  grn_plugin_expr_var_init(ctx, &vars[3], "query", -1);
+  grn_plugin_expr_var_init(ctx, &vars[4], "sortby", -1);
+  grn_plugin_expr_var_init(ctx, &vars[5], "output_columns", -1);
+  grn_plugin_expr_var_init(ctx, &vars[6], "offset", -1);
+  grn_plugin_expr_var_init(ctx, &vars[7], "limit", -1);
+  grn_plugin_expr_var_init(ctx, &vars[8], "frequency_threshold", -1);
+  grn_plugin_expr_var_init(ctx, &vars[9], "conditional_probability_threshold", -1);
+  grn_plugin_expr_var_init(ctx, &vars[10], "prefix_search", -1);
+  grn_plugin_expr_var_init(ctx, &vars[11], "similar_search", -1);
+  grn_plugin_command_create(ctx, "suggest", -1, command_suggest, 12, vars);
 
   grn_proc_create(ctx, CONST_STR_LEN("suggest_preparer"), GRN_PROC_FUNCTION,
                   func_suggest_preparer, NULL, NULL, 0, NULL);
