@@ -1,5 +1,5 @@
 /* -*- c-basic-offset: 2 -*- */
-/* Copyright(C) 2010-2012 Brazil
+/* Copyright(C) 2010-2013 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -35,7 +35,7 @@
 #include <netinet/in.h>
 #include <sys/resource.h>
 
-#include <zmq.h>
+#include "zmq_compatible.h"
 #include <event.h>
 #include <evhttp.h>
 #include <msgpack.h>
@@ -212,8 +212,8 @@ log_send(struct evkeyvalq *output_headers, struct evbuffer *res_buf,
       zmq_msg_t msg;
       if (!zmq_msg_init_size(&msg, sbuf.size)) {
         memcpy((void *)zmq_msg_data(&msg), sbuf.data, sbuf.size);
-        if (zmq_send(thd->zmq_sock, &msg, 0)) {
-          print_error("zmq_send() error");
+        if (zmq_msg_send(&msg, thd->zmq_sock, 0)) {
+          print_error("zmq_msg_send() error");
         }
         zmq_msg_close(&msg);
       }
@@ -494,7 +494,7 @@ recv_handler(grn_ctx *ctx, void *zmq_recv_sock, msgpack_zone *mempool, grn_obj *
   if (zmq_msg_init(&msg)) {
     print_error("cannot init zmq message.");
   } else {
-    if (zmq_recv(zmq_recv_sock, &msg, 0)) {
+    if (zmq_msg_recv(&msg, zmq_recv_sock, 0)) {
       print_error("cannot recv zmq message.");
     } else {
       msgpack_object obj;
@@ -593,7 +593,7 @@ serve_threads(int nthreads, int port, const char *db_path, void *zmq_ctx,
               threads[i].zmq_sock = NULL;
             } else {
               uint64_t hwm = 1;
-              zmq_setsockopt(threads[i].zmq_sock, ZMQ_HWM, &hwm, sizeof(uint64_t));
+              zmq_setsockopt(threads[i].zmq_sock, ZMQ_SNDHWM, &hwm, sizeof(uint64_t));
             }
           } else {
             threads[i].zmq_sock = NULL;
@@ -727,18 +727,18 @@ main(int argc, char **argv)
   /* parse options */
   {
     static grn_str_getopt_opt opts[] = {
-      {'c', NULL, NULL, 0, getopt_op_none}, /* deprecated */
-      {'t', "n-threads", NULL, 0, getopt_op_none},
-      {'h', "help", NULL, run_mode_usage, getopt_op_update},
-      {'p', "port", NULL, 0, getopt_op_none},
-      {'\0', "bind-address", NULL, 0, getopt_op_none}, /* not supported yet */
-      {'s', "send-endpoint", NULL, 0, getopt_op_none},
-      {'r', "receive-endpoint", NULL, 0, getopt_op_none},
-      {'l', "log-base-path", NULL, 0, getopt_op_none},
-      {'\0', "n-lines-per-log-file", NULL, 0, getopt_op_none},
-      {'d', "daemon", NULL, run_mode_daemon, getopt_op_update},
+      {'c', NULL, NULL, 0, GETOPT_OP_NONE}, /* deprecated */
+      {'t', "n-threads", NULL, 0, GETOPT_OP_NONE},
+      {'h', "help", NULL, run_mode_usage, GETOPT_OP_UPDATE},
+      {'p', "port", NULL, 0, GETOPT_OP_NONE},
+      {'\0', "bind-address", NULL, 0, GETOPT_OP_NONE}, /* not supported yet */
+      {'s', "send-endpoint", NULL, 0, GETOPT_OP_NONE},
+      {'r', "receive-endpoint", NULL, 0, GETOPT_OP_NONE},
+      {'l', "log-base-path", NULL, 0, GETOPT_OP_NONE},
+      {'\0', "n-lines-per-log-file", NULL, 0, GETOPT_OP_NONE},
+      {'d', "daemon", NULL, run_mode_daemon, GETOPT_OP_UPDATE},
       {'\0', "disable-max-fd-check", NULL, RUN_MODE_ENABLE_MAX_FD_CHECK,
-       getopt_op_off},
+       GETOPT_OP_OFF},
       {'\0', NULL, NULL, 0, 0}
     };
     opts[0].arg = &max_threads_string;
