@@ -24,10 +24,6 @@
 
 #include "../lib/grn-assertions.h"
 
-void test_nil_column_reference_value(void);
-void test_output_columns_with_space(void);
-void test_vector_geo_point(void);
-void test_vector_geo_point_with_query(void);
 void test_unmatched_output_columns(void);
 void test_vector_int32(void);
 void test_vector_text(void);
@@ -102,97 +98,6 @@ cut_teardown(void)
   remove_tmp_directory();
 }
 
-void
-test_nil_column_reference_value(void)
-{
-  const gchar *actual;
-
-  assert_send_commands("table_create Sites TABLE_PAT_KEY ShortText Int32\n"
-                       "column_create Sites link COLUMN_SCALAR Sites\n"
-                       "load --table Sites\n"
-                       "[\n"
-                       "[\"_key\",\"_value\"],\n"
-                       "[\"groonga.org\",0],\n"
-                       "[\"razil.jp\",0]\n"
-                       "]");
-  actual = send_command("select Sites");
-  cut_assert_equal_string("[[[2],"
-                          "[[\"_id\",\"UInt32\"],"
-                           "[\"_key\",\"ShortText\"],"
-                           "[\"link\",\"Sites\"]],"
-                          "[1,\"groonga.org\",\"\"],"
-                          "[2,\"razil.jp\",\"\"]]]", actual);
-}
-
-void
-test_output_columns_with_space(void)
-{
-  assert_send_commands("table_create Sites TABLE_HASH_KEY ShortText\n"
-                       "column_create Sites uri COLUMN_SCALAR ShortText\n"
-                       "load --table Sites\n"
-                       "[\n"
-                       "[\"_key\",\"uri\"],\n"
-                       "[\"groonga\",\"http://groonga.org/\"],\n"
-                       "[\"razil\",\"http://razil.jp/\"]\n"
-                       "]");
-  cut_assert_equal_string("[[[2],"
-                          "[[\"_key\",\"ShortText\"],"
-                           "[\"uri\",\"ShortText\"]],"
-                          "[\"groonga\",\"http://groonga.org/\"],"
-                          "[\"razil\",\"http://razil.jp/\"]]]",
-                          send_command("select Sites "
-                                       "--output_columns '_key, uri'"));
-}
-
-void
-test_vector_geo_point(void)
-{
-  assert_send_command("table_create Shops TABLE_HASH_KEY ShortText");
-  assert_send_command("column_create Shops places COLUMN_VECTOR WGS84GeoPoint");
-  assert_send_command("load "
-                      "'["
-                      "[\"_key\",\"places\"],"
-                      "[\"daruma\","
-                      "[\"130094061x505025099\",\"130185500x505009000\"]]"
-                      "]' "
-                      "Shops");
-  cut_assert_equal_string("[["
-                          "[1],"
-                          "["
-                          "[\"_id\",\"UInt32\"],"
-                          "[\"_key\",\"ShortText\"],"
-                          "[\"places\",\"WGS84GeoPoint\"]"
-                          "],"
-                          "[1,\"daruma\","
-                          "[\"130094061x505025099\",\"130185500x505009000\"]]"
-                          "]]",
-                          send_command("select Shops"));
-}
-
-void
-test_vector_geo_point_with_query(void)
-{
-  assert_send_command("table_create Shops TABLE_HASH_KEY ShortText");
-  assert_send_command("column_create Shops places COLUMN_VECTOR WGS84GeoPoint");
-  assert_send_command("load "
-                      "'["
-                      "[\"_key\",\"places\"],"
-                      "[\"daruma\","
-                      "[\"130094061x505025099\",\"130185500x505009000\"]]"
-                      "]' "
-                      "Shops");
-  cut_assert_equal_string("[["
-                          "[1],"
-                          "["
-                          "[\"_id\",\"UInt32\"],"
-                          "[\"_key\",\"ShortText\"],"
-                          "[\"places\",\"WGS84GeoPoint\"]"
-                          "],"
-                          "[1,\"daruma\","
-                          "[\"130094061x505025099\",\"130185500x505009000\"]]"
-                          "]]",
-                          send_command("select Shops --query _key:daruma"));
-}
 
 void
 test_unmatched_output_columns(void)
