@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2; coding: utf-8 -*- */
 /*
-  Copyright (C) 2008-2009  Kouhei Sutou <kou@cozmixng.org>
+  Copyright (C) 2008-2012  Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -13,7 +13,7 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #include "test-hash.h"
@@ -734,11 +734,11 @@ test_value(gconstpointer data)
   cut_assert_open_cursor();
   while (grn_hash_cursor_next(context, cursor) != GRN_ID_NIL) {
     void *key;
-    gchar *null_terminated_key;
+    const gchar *null_terminated_key;
     int size;
 
     size = grn_hash_cursor_get_key(context, cursor, &key);
-    null_terminated_key = g_string_free(g_string_new_len(key, size), FALSE);
+    null_terminated_key = cut_take_strndup(key, size);
     if (g_str_equal(null_terminated_key, key2)) {
       grn_hash_cursor_set_value(context, cursor, value2, GRN_OBJ_SET);
     } else if (g_str_equal(null_terminated_key, key4)) {
@@ -799,11 +799,11 @@ test_delete(gconstpointer data)
   cut_assert_open_cursor();
   while (grn_hash_cursor_next(context, cursor) != GRN_ID_NIL) {
     void *key;
-    gchar *null_terminated_key;
+    const gchar *null_terminated_key;
     int size;
 
     size = grn_hash_cursor_get_key(context, cursor, &key);
-    null_terminated_key = g_string_free(g_string_new_len(key, size), FALSE);
+    null_terminated_key = cut_take_strndup(key, size);
     if (g_str_equal(null_terminated_key, key1) ||
         g_str_equal(null_terminated_key, key5)) {
       grn_hash_cursor_delete(context, cursor, NULL);
