@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2; coding: utf-8 -*- */
 /*
-  Copyright (C) 2010-2011  Kouhei Sutou <kou@clear-code.com>
+  Copyright (C) 2010-2014  Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -363,7 +363,7 @@ test_geo_point_wgs84(void)
 {
   gint takane_latitude, takane_longitude;
 
-  takane_latitude = grn_test_coordinate_in_milliseconds(35.69869);
+  takane_latitude = grn_test_coordinate_in_milliseconds(35.6986901);
   takane_longitude = grn_test_coordinate_in_milliseconds(139.56099);
 
   geo_point_wgs84 = grn_obj_open(context, GRN_BULK, 0, GRN_DB_WGS84_GEO_POINT);
@@ -386,7 +386,8 @@ test_array_empty(void)
                           "value:(nil) "
                           "size:0 "
                           "columns:[] "
-                          "ids:[]"
+                          "ids:[] "
+                          "subrec:none"
                           ">",
                           inspected_string());
 }
@@ -405,7 +406,8 @@ test_array_with_records(void)
                           "value:(nil) "
                           "size:2 "
                           "columns:[name] "
-                          "ids:[1, 2]"
+                          "ids:[1, 2] "
+                          "subrec:none"
                           ">",
                           inspected_string());
 }
@@ -422,7 +424,9 @@ test_hash_empty(void)
                           "size:0 "
                           "columns:[] "
                           "default_tokenizer:(nil) "
-                          "keys:[]"
+                          "normalizer:(nil) "
+                          "keys:[] "
+                          "subrec:none"
                           ">",
                           inspected_string());
 }
@@ -447,7 +451,9 @@ test_hash_with_records(void)
                           "size:2 "
                           "columns:[name] "
                           "default_tokenizer:(nil) "
-                          "keys:[\"groonga.org\", \"razil.jp\"]"
+                          "normalizer:(nil) "
+                          "keys:[\"groonga.org\", \"razil.jp\"] "
+                          "subrec:none"
                           ">",
                           inspected_string());
 }
@@ -464,7 +470,9 @@ test_patricia_trie_empty(void)
                           "size:0 "
                           "columns:[] "
                           "default_tokenizer:(nil) "
+                          "normalizer:(nil) "
                           "keys:[] "
+                          "subrec:none "
                           "nodes:{}"
                           ">",
                           inspected_string());
@@ -491,7 +499,9 @@ test_patricia_trie_with_records(void)
     "size:2 "
     "columns:[name] "
     "default_tokenizer:(nil) "
+    "normalizer:(nil) "
     "keys:[\"groonga.org\", \"razil.jp\"] "
+    "subrec:none "
     "nodes:{\n"
     "2(\"razil.jp\"){0,3,0}[01110010 01100001 01111010 01101001 "
                            "01101100 00101110 01101010 01110000]\n"
@@ -574,11 +584,12 @@ test_uvector_with_records(void)
   GRN_RECORD_PUT(context, uvector, 1);
   GRN_RECORD_PUT(context, uvector, 2);
   inspected = grn_inspect(context, NULL, uvector);
-  cut_assert_equal_string("["
-                          "#<record:pat:Sites id:1 key:\"groonga.org\">, "
-                          "#<record:pat:Sites id:2 key:\"razil.jp\">"
-                          "]",
-                          inspected_string());
+  cut_assert_equal_string(
+    "["
+    "#<element record:#<record:pat:Sites id:1 key:\"groonga.org\">, weight:0>, "
+    "#<element record:#<record:pat:Sites id:2 key:\"razil.jp\">, weight:0>"
+    "]",
+    inspected_string());
 }
 
 void
@@ -678,7 +689,6 @@ data_accessor_dynamic_pseudo_column_name(void)
                  NULL)
 
   ADD_DATUM("_score");
-  ADD_DATUM("_nsubrecs");
 
 #undef ADD_DATUM
 }
