@@ -13,7 +13,7 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #include <groonga.h>
@@ -998,24 +998,24 @@ data_near_geo_point(void)
                  NULL)
 
   ADD_DATA("no limit",
-           gcut_list_string_new(POINT(1, 2, 3,
-                                      4, 5, 6),
-                                POINT(1, 2, 3,
-                                      7, 8, 9),
-                                POINT(7, 8, 9,
-                                      4, 5, 6),
-                                POINT(88, 58, 58,
-                                      178, 58, 58),
-                                POINT(89, 59, 59,
-                                      179, -59, -59),
-                                POINT(89, 59, 59,
-                                      179, 59, 59),
-                                POINT(-89, -59, -59,
-                                      179, 59, 59),
-                                POINT(-89, -59, -59,
-                                      -179, -59, -59),
-                                POINT(-88, -58, -58,
-                                      -178, -58, -58),
+           gcut_list_string_new(TAKEN_POINT(1, 2, 3,
+                                            4, 5, 6),
+                                TAKEN_POINT(1, 2, 3,
+                                            7, 8, 9),
+                                TAKEN_POINT(7, 8, 9,
+                                            4, 5, 6),
+                                TAKEN_POINT(88, 58, 58,
+                                            178, 58, 58),
+                                TAKEN_POINT(89, 59, 59,
+                                            179, -59, -59),
+                                TAKEN_POINT(89, 59, 59,
+                                            179, 59, 59),
+                                TAKEN_POINT(-89, -59, -59,
+                                            179, 59, 59),
+                                TAKEN_POINT(-89, -59, -59,
+                                            -179, -59, -59),
+                                TAKEN_POINT(-88, -58, -58,
+                                            -178, -58, -58),
                                 NULL),
            0,
            TAKEN_POINT(0, 0, 0,
@@ -1023,12 +1023,12 @@ data_near_geo_point(void)
            0, -1,
            0);
   ADD_DATA("min-size",
-           gcut_list_string_new(POINT(1, 2, 3,
-                                      4, 5, 6),
-                                POINT(1, 2, 3,
-                                      7, 8, 9),
-                                POINT(7, 8, 9,
-                                      4, 5, 6),
+           gcut_list_string_new(TAKEN_POINT(1, 2, 3,
+                                            4, 5, 6),
+                                TAKEN_POINT(1, 2, 3,
+                                            7, 8, 9),
+                                TAKEN_POINT(7, 8, 9,
+                                            4, 5, 6),
                                 NULL),
            1,
            TAKEN_POINT(0, 0, 0,
