@@ -161,6 +161,16 @@ grn_rc_to_string(grn_rc rc)
     return "GRN_INCOMPATIBLE_FILE_FORMAT";
   case GRN_UPDATE_NOT_ALLOWED:
     return "GRN_UPDATE_NOT_ALLOWED";
+  case GRN_TOO_SMALL_OFFSET:
+    return "GRN_TOO_SMALL_OFFSET";
+  case GRN_TOO_LARGE_OFFSET:
+    return "GRN_TOO_LARGE_OFFSET";
+  case GRN_TOO_SMALL_LIMIT:
+    return "GRN_TOO_SMALL_LIMIT";
+  case GRN_CAS_ERROR:
+    return "GRN_CAS_ERROR";
+  case GRN_UNSUPPORTED_COMMAND_VERSION:
+    return "GRN_UNSUPPORTED_COMMAND_VERSION";
   default:
     return cut_take_printf("GRN_UNKNOWN_STATUS (%d)", rc);
   }
@@ -723,40 +733,6 @@ grn_test_table_collect_string(grn_ctx          *context,
   return records;
 }
 
-const GList *
-grn_test_view_collect_string(grn_ctx          *context,
-                             grn_obj          *view,
-                             const gchar      *text_column_name)
-{
-  GList *records = NULL;
-  grn_table_cursor *cursor;
-  grn_obj id, value;
-  grn_obj *text_column;
-
-  cursor = grn_table_cursor_open(context, view, NULL, 0, NULL, 0,
-                                 0, -1, GRN_CURSOR_ASCENDING);
-  cut_assert_not_null(cursor);
-  GRN_TEXT_INIT(&id, 0);
-  GRN_TEXT_INIT(&value, 0);
-  text_column = grn_obj_column(context, view,
-                               text_column_name, strlen(text_column_name));
-  while (grn_table_cursor_next_o(context, cursor, &id) == GRN_SUCCESS) {
-    GRN_BULK_REWIND(&value);
-    grn_obj_get_value_o(context, text_column, &id, &value);
-    records = g_list_append(records, g_strndup(GRN_TEXT_VALUE(&value),
-                                               GRN_TEXT_LEN(&value)));
-  }
-  grn_obj_unlink(context, &id);
-  grn_obj_unlink(context, &value);
-  grn_obj_unlink(context, text_column);
-  gcut_take_list(records, g_free);
-
-  grn_test_assert(grn_table_cursor_close(context, cursor));
-  grn_test_assert_context(context);
-
-  return records;
-}
-
 gint
 grn_test_coordinate_in_milliseconds(gdouble coordinate_in_degree)
 {
