@@ -22,14 +22,6 @@
 #include "../lib/grn-assertions.h"
 
 void test_in_circle(void);
-void test_in_rectangle_long_latitude(void);
-void test_in_rectangle_long_longitude(void);
-void test_in_rectangle_same_locations(void);
-void test_in_rectangle_over_border(void);
-void test_in_rectangle_over_top_left_latitude(void);
-void test_in_rectangle_over_top_left_longitude(void);
-void test_in_rectangle_over_bottom_right_latitude(void);
-void test_in_rectangle_over_bottom_right_longitude(void);
 void test_sort(void);
 void test_filter_by_tag_and_sort_by_distance_from_tokyo_tocho(void);
 void test_in_circle_and_tag(void);
@@ -134,174 +126,6 @@ test_in_circle(void)
         grn_test_location_string(yurakucho_latitude, yurakucho_longitude))));
 }
 
-void
-test_in_rectangle_long_latitude(void)
-{
-  gdouble sugamo_latitude = 35.73360;
-  gdouble sugamo_longitude = 139.7394;
-  gdouble daiba_latitude = 35.62614;
-  gdouble daiba_longitude = 139.7714;
-  gdouble budoukan_latitude = 35.69328;
-  gdouble budoukan_longitude = 139.74968;
-
-  cut_assert_equal_string(
-    "[[[5],"
-    "[[\"name\",\"ShortText\"],[\"_score\",\"Int32\"],"
-     "[\"location\",\"WGS84GeoPoint\"]],"
-    "[\"たい焼き鉄次 大丸東京店\",2186,\"128451283x503166852\"],"
-    "[\"たいやき神田達磨 八重洲店\",2296,\"128453260x503174156\"],"
-    "[\"銀座 かずや\",2415,\"128424629x503139222\"],"
-    "[\"根津のたいやき\",3210,\"128592911x503145263\"],"
-    "[\"築地 さのきや\",3579,\"128397312x503174596\"]"
-    "]]",
-    send_command(
-      cut_take_printf(
-        "select Shops "
-        "--sortby '+_score, +name' "
-        "--output_columns 'name, _score, location' "
-        "--filter 'geo_in_rectangle(location, \"%s\", \"%s\")' "
-        "--scorer '_score=geo_distance(location, \"%s\")'",
-        grn_test_location_string(sugamo_latitude, sugamo_longitude),
-        grn_test_location_string(daiba_latitude, daiba_longitude),
-        grn_test_location_string(budoukan_latitude, budoukan_longitude))));
-}
-
-void
-test_in_rectangle_long_longitude(void)
-{
-  gdouble takada_no_baba_latitude = 35.7121;
-  gdouble takada_no_baba_longitude = 139.7038;
-  gdouble tsukiji_latitude = 35.6684;
-  gdouble tsukiji_longitude = 139.7727;
-  gdouble budoukan_latitude = 35.69328;
-  gdouble budoukan_longitude = 139.74968;
-
-  cut_assert_equal_string(
-    "[[[3],"
-    "[[\"name\",\"ShortText\"],[\"_score\",\"Int32\"],"
-     "[\"location\",\"WGS84GeoPoint\"]],"
-    "[\"たい焼き鉄次 大丸東京店\",2186,\"128451283x503166852\"],"
-    "[\"たいやき神田達磨 八重洲店\",2296,\"128453260x503174156\"],"
-    "[\"銀座 かずや\",2415,\"128424629x503139222\"]"
-    "]]",
-    send_command(
-      cut_take_printf(
-        "select Shops "
-        "--sortby '+_score, +name' "
-        "--output_columns 'name, _score, location' "
-        "--filter 'geo_in_rectangle(location, \"%s\", \"%s\")' "
-        "--scorer '_score=geo_distance(location, \"%s\")'",
-        grn_test_location_string(takada_no_baba_latitude,
-                                 takada_no_baba_longitude),
-        grn_test_location_string(tsukiji_latitude, tsukiji_longitude),
-        grn_test_location_string(budoukan_latitude, budoukan_longitude))));
-}
-
-void
-test_in_rectangle_same_locations(void)
-{
-  gdouble takada_no_baba_latitude = 35.7121;
-  gdouble takada_no_baba_longitude = 139.7038;
-  gdouble budoukan_latitude = 35.69328;
-  gdouble budoukan_longitude = 139.74968;
-
-  cut_assert_equal_string(
-    "[[[0],"
-    "[[\"name\",\"ShortText\"],[\"_score\",\"Int32\"],"
-     "[\"location\",\"WGS84GeoPoint\"]]"
-    "]]",
-    send_command(
-      cut_take_printf(
-        "select Shops "
-        "--sortby '+_score, +name' "
-        "--output_columns 'name, _score, location' "
-        "--filter 'geo_in_rectangle(location, \"%s\", \"%s\")' "
-        "--scorer '_score=geo_distance(location, \"%s\")'",
-        grn_test_location_string(takada_no_baba_latitude,
-                                 takada_no_baba_longitude),
-        grn_test_location_string(takada_no_baba_latitude,
-                                 takada_no_baba_longitude),
-        grn_test_location_string(budoukan_latitude, budoukan_longitude))));
-}
-
-void
-test_in_rectangle_over_border(void)
-{
-  grn_test_assert_send_command_error(
-    context,
-    GRN_FUNCTION_NOT_IMPLEMENTED,
-    "geo_in_rectangle(): negative coordinate is not implemented.",
-    "select Shops "
-    "--sortby '+name' "
-    "--output_columns 'name, location' "
-    "--filter 'geo_in_rectangle(location, "
-    "\"35.73360x-139.7394\", \"-35.62614x139.7714\")'");
-}
-
-void
-test_in_rectangle_over_top_left_latitude(void)
-{
-  grn_test_assert_send_command_error(
-    context,
-    GRN_INVALID_ARGUMENT,
-    "geo_in_rectangle(): top left point's latitude is too big: "
-    "<324000000>(max:324000000): "
-    "(324000000,503061840) (128254104,50317704",
-    "select Shops "
-    "--sortby '+name' "
-    "--output_columns 'name, location' "
-    "--filter "
-    "'geo_in_rectangle(location, \"90.0x139.7394\", \"35.62614x139.7714\")'");
-}
-
-void
-test_in_rectangle_over_top_left_longitude(void)
-{
-  grn_test_assert_send_command_error(
-    context,
-    GRN_INVALID_ARGUMENT,
-    "geo_in_rectangle(): top left point's longitude is too big: "
-    "<648000000>(max:648000000): "
-    "(128640960,648000000) (128254104,5031770",
-    "select Shops "
-    "--sortby '+name' "
-    "--output_columns 'name, location' "
-    "--filter "
-    "'geo_in_rectangle(location, \"35.73360x180.0\", \"35.62614x139.7714\")'");
-}
-
-void
-test_in_rectangle_over_bottom_right_latitude(void)
-{
-  grn_test_assert_send_command_error(
-    context,
-    GRN_INVALID_ARGUMENT,
-    "geo_in_rectangle(): bottom right point's latitude is too big: "
-    "<324000000>(max:324000000): "
-    "(128640960,503061840) (324000000,5031",
-    "select Shops "
-    "--sortby '+name' "
-    "--output_columns 'name, location' "
-    "--filter "
-    "'geo_in_rectangle(location, \"35.73360x139.7394\", \"90.0x139.7714\")'");
-}
-
-void
-test_in_rectangle_over_bottom_right_longitude(void)
-{
-  grn_test_assert_send_command_error(
-    context,
-    GRN_INVALID_ARGUMENT,
-    "geo_in_rectangle(): bottom right point's longitude is too big: "
-    "<648000000>(max:648000000): "
-    "(128640960,503061840) (128254104,648",
-    "select Shops "
-    "--sortby '+name' "
-    "--output_columns 'name, location' "
-    "--filter "
-    "'geo_in_rectangle(location, \"35.73360x139.7394\", \"35.62614x180.0\")'");
-}
-
 void
 test_sort(void)
 {
